==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.server/src/com/openexchange/net/ssl/management/json/action/StoreSSLCertificateAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2017-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.management.json.action;

import org.json.JSONObject;
import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.exception.OXException;
import com.openexchange.java.Strings;
import com.openexchange.net.ssl.management.DefaultCertificate;
import com.openexchange.net.ssl.management.SSLCertificateManagementService;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.servlet.AjaxExceptionCodes;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link StoreSSLCertificateAction}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class StoreSSLCertificateAction extends AbstractSSLCertificateManagementAction {

    /**
     * Initialises a new {@link StoreSSLCertificateAction}.
     */
    public StoreSSLCertificateAction(ServiceLookup services) {
        super(services);
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
     */
    @Override
    public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
        // Try storing from cache
        String fingerprint = requestData.getParameter("fingerprint", String.class, true);
        if (!Strings.isEmpty(fingerprint)) {
            String hostname = requestData.getParameter("hostname", String.class, false);
            Boolean trust = requestData.getParameter("trust", Boolean.class, false);

            SSLCertificateManagementService managementService = getService(SSLCertificateManagementService.class);

            DefaultCertificate.Builder certificate = DefaultCertificate.builder()
                .fingerprint(fingerprint)
                .hostName(hostname)
                .trusted(null != trust && trust.booleanValue());

            managementService.store(session.getUserId(), session.getContextId(), certificate.build());

            return new AJAXRequestResult();
        }

        // Try from payload
        Object obj = requestData.getData();
        if (!(obj instanceof JSONObject)) {
            throw AjaxExceptionCodes.INVALID_REQUEST_BODY.create("JSONObject", obj.getClass());
        }

        JSONObject data = (JSONObject) requestData.getData();
        SSLCertificateManagementService managementService = getService(SSLCertificateManagementService.class);
        managementService.store(session.getUserId(), session.getContextId(), parse(data));

        return new AJAXRequestResult();
    }
}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.server/src/com/openexchange/net/ssl/management/json/action/StoreSSLCertificateAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2017-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.management.json.action;

import org.json.JSONObject;
import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.exception.OXException;
import com.openexchange.java.Strings;
import com.openexchange.net.ssl.management.DefaultCertificate;
import com.openexchange.net.ssl.management.SSLCertificateManagementService;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.servlet.AjaxExceptionCodes;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link StoreSSLCertificateAction}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class StoreSSLCertificateAction extends AbstractSSLCertificateManagementAction {

    /**
     * Initialises a new {@link StoreSSLCertificateAction}.
     */
    public StoreSSLCertificateAction(ServiceLookup services) {
        super(services);
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
     */
    @Override
    public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
        // Try storing from cache
        String fingerprint = requestData.getParameter("fingerprint", String.class, true);
        if (Strings.isNotEmpty(fingerprint)) {
            String hostname = requestData.getParameter("hostname", String.class, false);
            Boolean trust = requestData.getParameter("trust", Boolean.class, false);

            SSLCertificateManagementService managementService = getService(SSLCertificateManagementService.class);

            DefaultCertificate.Builder certificate = DefaultCertificate.builder()
                .fingerprint(fingerprint)
                .hostName(hostname)
                .trusted(null != trust && trust.booleanValue());

            managementService.store(session.getUserId(), session.getContextId(), certificate.build());

            return new AJAXRequestResult();
        }

        // Try from payload
        Object obj = requestData.getData();
        if (!(obj instanceof JSONObject)) {
            throw AjaxExceptionCodes.INVALID_REQUEST_BODY.create("JSONObject", obj.getClass());
        }

        JSONObject data = (JSONObject) requestData.getData();
        SSLCertificateManagementService managementService = getService(SSLCertificateManagementService.class);
        managementService.store(session.getUserId(), session.getContextId(), parse(data));

        return new AJAXRequestResult();
    }
}
